.zindex-1 {
  z-index: 1 !important;
}

.cursor-default {
  cursor: default !important;
}

.line-height-18 {
  line-height: 1.8rem !important;
}

.d-inline-nextSibling + div {
  display: inline-block !important;
}

.w-10 {
  width: 10% !important;
}

.w-30 {
  width: 30% !important;
}

.w-40 {
  width: 40% !important;
}

.r-50 {
  right: 50% !important;
}

.text-ellipsis {
  text-overflow: ellipsis;
  overflow: hidden;
}

/* .pr-05, .px-05 {
  padding-right: .25rem !important;
}

.pl-05, .px-05 {
  padding-left: .25rem !important;
} */

.pt-025, .px-025 {
  padding-top: .125rem !important;
}
/*
.pb-05, .px-05 {
  padding-bottom: .25rem !important;
} */

.h-2 {
  height: 0.75rem !important;
}

.h-3 {
  height: 1.25rem !important;
}

.bg-transparent {
  background-color: transparent !important;
}

.bg-blue-light-hover:hover {
  background-color:#dae4f1 !important;
}

.active > .btn {
  background-color: #c6d2e1 !important;
}

.active > .btn.remove-bg {
  background-color: transparent !important;
  border: 1px solid #dee2e6 !important;
}

.color-gray-dark {
  color: #273d56 !important;
}

.color-text {
  color: #1f3349 !important;
}

.color-blue-on-hover:hover {
  color: #4264fb !important;
}

.text-decoration-none {
  text-decoration: none;
}

/* Remove controls from Firefox */
input[type=number] {
  -moz-appearance: textfield;
}

input[type=number]::-webkit-inner-spin-button,
input[type=number]::-webkit-outer-spin-button {
  -webkit-appearance: none;
  border: solid 1px darkgray;
  margin: 0;
}

input[type="color"] {
    -webkit-appearance: none;
    padding: 0 !important;
}
input[type="color"]::-webkit-color-swatch-wrapper {
    padding: 0 !important;
}



/* /////////////////// Scroll Bar ////////////////////// */
/* width */

.scrollbar {
  overflow-y: scroll;
}

.scrollbar::-webkit-scrollbar {
  width: 6px;
}

/* Track */
.scrollbar::-webkit-scrollbar-track {
  box-shadow: inset 0 0 5px #d3deec;
  border-radius: 10px;
}

/* Handle */
.scrollbar::-webkit-scrollbar-thumb {
  background: #dae4f1;
  border-radius: 10px;
}

/* Handle on hover */
.scrollbar::-webkit-scrollbar-thumb:hover {
  background: #c6d2e1;
}

.scrollbar::-moz-scrollbar{
  width: 6px;
}

/* Track */
.scrollbar::-moz-scrollbar-track{
  box-shadow: inset 0 0 5px grey;
  border-radius: 10px;
}

/* Handle */
.scrollbar::-moz-scrollbar-thum {
  background: #cacdcf;
  border-radius: 10px;
}

/* Handle on hover */
.scrollbar::-moz-scrollbar-thumb:hover {
  background: #b5b6b7;
}
